# concentrator_calculator
 A small calculater to compute the time needed for volume reductions in an eppendorf concentrator.

 **Preheat the concentrator to the desired temperature for at least 30 minutes.**

## Installation
`pip install concentrator-calculator`

## How to start
Open terminal and type:

`concentrator_calculator`
